@@ -8,6 +8,8 @@ from typing import Callable, Dict, List, Optional, Tuple
 from snowflake.connector import SnowflakeConnection
 from snowflake.connector.cursor import SnowflakeCursor
 
+from metaphor.snowflake.filter import DatabaseFilter, SnowflakeFilter
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
@@ -87,3 +89,45 @@ def async_execute(
                 results_processor(key, results)
 
         return results_map
+
+
+def include_table(
+    database: str, schema: str, table: str, filter: SnowflakeFilter
+) -> bool:
+    database_lower = database.lower()
+    schema_lower = schema.lower()
+    table_lower = table.lower()
+
+    def covered_by_filter(database_filter: DatabaseFilter):
+        # not covered by database filter
+        if database_lower not in database_filter:
+            return False
+
+        schema_filter = database_filter[database_lower]
+
+        # empty schema filter
+        if schema_filter is None or len(schema_filter) == 0:
+            return True
+
+        # not covered by schema filter
+        if schema_lower not in schema_filter:
+            return False
+
+        table_filter = schema_filter[schema_lower]
+
+        # empty table filter
+        if table_filter is None or len(table_filter) == 0:
+            return True
+
+        # covered by table filter?
+        return table_lower in table_filter
+
+    # Filtered out by includes
+    if filter.includes is not None and not covered_by_filter(filter.includes):
+        return False
+
+    # Filtered out by excludes
+    if filter.excludes is not None and covered_by_filter(filter.excludes):
+        return False
+
+    return True
